@@ -15,6 +15,7 @@
 #  limitations under the License.
 from functools import wraps
 import random
+import asyncio
 
 import sys
 from os import path
@@ -1683,7 +1684,7 @@ class Update(MethodsInterface):
         retval = []
         skip_check_status = False
         actual_reason = self.Reason.UnknownError
-        for binhost in sorted(binhosts_data.get_binhosts(), reverse=True):
+        for binhost in sorted(asyncio.run(binhosts_data.get_asyncbinhosts()), reverse=True):
             host = binhost.host
             if not binhost.valid:
                 reason = self.Reason.WrongBinhost 
