@@ -91,10 +91,12 @@ def get_synchronization_tasks(object_name):
                   'method': Object(f'detect_best_binhost({object_name.lower()}.cl_update_ignore_level)'),
                   'essential': False,
                   'depend': (Tasks.success() & ~AllTasks.has_any("not_use_search") &
-                             (~AllTasks.success_one_of("check_current_binhost") |
+                             (AllTasks.failed_one_of("check_current_binhost") |
+                              AllTasks.failed_one_of("check_chosen_binhost") |
+                              (AllTasks.hasnot("check_current_binhost") &
+                               AllTasks.hasnot("check_chosen_binhost")) |
                              AllTasks.success_all("sync_reps"))),
                   'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'off',
-                  'depend': AllTasks.hasnot("check_chosen_binhost"),
                  },
                  {'name': 'interrupt_on_no_leveled_binhost',
                   'method': Object("interrupt_on_no_leveled_binhost()"),
